summaryrefslogtreecommitdiffstats
path: root/chrome/common/chrome_switches.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/chrome_switches.cc')
-rw-r--r--chrome/common/chrome_switches.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index 2224e39..1cfc40e7 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -17,12 +17,12 @@ const wchar_t kDisableHangMonitor[] = L"disable-hang-monitor";
// Completely disables UMA metrics system.
const wchar_t kDisableMetrics[] = L"disable-metrics";
-// Disables only the sending of metrics reports. In contrast to
-// kDisableMetrics, this executes all the code that a normal client would use
-// for reporting, except the report is dropped rather than sent to the server.
-// This is useful for finding issues in the metrics code during UI and
-// performance tests.
-const wchar_t kDisableMetricsReporting[] = L"disable-metrics-reporting";
+// Enables the recording of metrics reports but disables reporting.
+// In contrast to kDisableMetrics, this executes all the code that a normal
+// client would use for reporting, except the report is dropped rather than sent
+// to the server. This is useful for finding issues in the metrics code during
+// UI and performance tests.
+const wchar_t kMetricsRecordingOnly[] = L"metrics-recording-only";
// Causes the browser process to throw an assertion on startup.
const wchar_t kBrowserAssertTest[] = L"assert-test";